@@ -16,6 +16,7 @@ from typing import Union, List
 from dataclasses import dataclass, field, asdict
 from datetime import datetime, timezone
 import time
+import json
 
 from .error_codes import X19Error, WhatsminerError, BraiinsOSError
 
@@ -70,11 +71,11 @@ class MinerData:
     model: str = "Unknown"
     hostname: str = "Unknown"
     hashrate: float = 0
-    left_board_hashrate: float = 0
-    center_board_hashrate: float = 0
-    right_board_hashrate: float = 0
+    left_board_hashrate: float = 0.0
+    center_board_hashrate: float = 0.0
+    right_board_hashrate: float = 0.0
     temperature_avg: int = field(init=False)
-    env_temp: float = 0
+    env_temp: float = 0.0
     left_board_temp: int = 0
     left_board_chip_temp: int = 0
     center_board_temp: int = 0
@@ -118,7 +119,7 @@ class MinerData:
         return setattr(self, key, value)
 
     def __iter__(self):
-        return iter([item for item in self.__dict__])
+        return iter([item for item in self.asdict()])
 
     @property
     def total_chips(self):  # noqa - Skip PyCharm inspection
@@ -177,6 +178,11 @@ class MinerData:
     def asdict(self):
         return asdict(self)
 
+    def as_json(self):
+        data = self.asdict()
+        data["datetime"] = str(int(time.mktime(data["datetime"].timetuple())))
+        return json.dumps(data)
+
     def as_influxdb(self, measurement_name: str = "miner_data"):
         tag_data = [measurement_name]
         field_data = []
@@ -184,7 +190,8 @@ class MinerData:
         tags = ["ip", "mac", "model", "hostname"]
         for attribute in self:
             if attribute in tags:
-                tag_data.append(f"{attribute}={self[attribute]}")
+                escaped_data = self[attribute].replace(" ", "\\ ")
+                tag_data.append(f"{attribute}={escaped_data}")
                 continue
             if isinstance(self[attribute], str):
                 field_data.append(f'{attribute}="{self[attribute]}"')
@@ -195,6 +202,9 @@ class MinerData:
             if isinstance(self[attribute], int):
                 field_data.append(f"{attribute}={self[attribute]}")
                 continue
+            if isinstance(self[attribute], float):
+                field_data.append(f"{attribute}={self[attribute]}")
+                continue
             if attribute == "fault_light" and not self[attribute]:
                 field_data.append(f"{attribute}=false")
                 continue
